# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/Sharing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Policy_pb2 as sharepubapi__v1_dot_Policy__pb2
from . import DataEntry_pb2 as sharepubapi__v1_dot_DataEntry__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2
from devicepubapi_v1 import StaticCredentialAuth_pb2 as devicepubapi__v1_dot_StaticCredentialAuth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csharepubapi_v1/Sharing.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1bsharepubapi_v1/Policy.proto\x1a\x1esharepubapi_v1/DataEntry.proto\x1a\x1b\x63ompubapi_v1/Metadata.proto\x1a\"compubapi_v1/IdentityProfile.proto\x1a*devicepubapi_v1/StaticCredentialAuth.proto\"\xba\x04\n\x13StartSharingRequest\x12\x16\n\x0e\x63orrelation_id\x18\x01 \x01(\t\x12\x30\n\x06policy\x18\x02 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x15\n\rattribute_ids\x18\x03 \x03(\x0c\x12\x13\n\x0bwrapped_key\x18\x04 \x01(\x0c\x12\x12\n\ncredential\x18\x05 \x01(\x0c\x12\x11\n\tauth_list\x18\x06 \x01(\x0c\x12\x18\n\x0bttl_seconds\x18\x07 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\rone_time_only\x18\x08 \x01(\x08H\x01\x88\x01\x01\x12\x37\n\nextra_data\x18\t \x03(\x0b\x32#.yoti.core.sharepubapi_v1.DataEntry\x12\x1a\n\x12\x62illing_account_id\x18\n \x01(\t\x12\x19\n\x11\x62illing_source_id\x18\x0b \x01(\t\x12\x30\n\x07subject\x18\x0c \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Subject\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12P\n\x16static_credential_auth\x18\xb8\x17 \x01(\x0b\x32/.yoti.core.devicepubapi_v1.StaticCredentialAuthB\x0e\n\x0c_ttl_secondsB\x10\n\x0e_one_time_only\"\x80\x01\n\x14StartSharingResponse\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x30\n\x06policy\x18\x02 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x1f\n\x17sharing_token_for_stats\x18\x03 \x01(\t\"\xf1\x03\n\x16\x43ompleteSharingRequest\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\x30\n\x06policy\x18\x03 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x15\n\rattribute_ids\x18\x04 \x03(\x0c\x12\x13\n\x0bwrapped_key\x18\x05 \x01(\x0c\x12\x12\n\ncredential\x18\x06 \x01(\x0c\x12\x11\n\tauth_list\x18\x07 \x01(\x0c\x12\x14\n\x0csession_data\x18\x08 \x01(\t\x12\x30\n\x06issuer\x18\t \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\n \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12\x37\n\nextra_data\x18\x0b \x03(\x0b\x32#.yoti.core.sharepubapi_v1.DataEntry\x12\x14\n\x0creference_id\x18\x0c \x01(\t\x12\x18\n\x10mobile_device_id\x18\r \x01(\t\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata*7\n\x06Issuer\x12\x08\n\x04\x43ORE\x10\x00\x12\x0b\n\x07\x43ONNECT\x10\x01\x12\n\n\x06PORTAL\x10\x02\x12\n\n\x06MOBILE\x10\x03*0\n\tTransport\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03URI\x10\x01\x12\x0b\n\x07QR_CODE\x10\x02\x42h\n\x17\x63om.yoti.sharepubapi_v1B\x0cSharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Sharing_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\014SharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _ISSUER._serialized_start=1432
  _ISSUER._serialized_end=1487
  _TRANSPORT._serialized_start=1489
  _TRANSPORT._serialized_end=1537
  _STARTSHARINGREQUEST._serialized_start=229
  _STARTSHARINGREQUEST._serialized_end=799
  _STARTSHARINGRESPONSE._serialized_start=802
  _STARTSHARINGRESPONSE._serialized_end=930
  _COMPLETESHARINGREQUEST._serialized_start=933
  _COMPLETESHARINGREQUEST._serialized_end=1430
# @@protoc_insertion_point(module_scope)
