# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/DataEntry.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esharepubapi_v1/DataEntry.proto\x12\x18yoti.core.sharepubapi_v1\"\xe7\x01\n\tDataEntry\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.yoti.core.sharepubapi_v1.DataEntry.Type\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x92\x01\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07INVOICE\x10\x01\x12\x17\n\x13PAYMENT_TRANSACTION\x10\x02\x12\x0c\n\x08LOCATION\x10\x03\x12\x0f\n\x0bTRANSACTION\x10\x04\x12\x1b\n\x17\x41GE_VERIFICATION_SECRET\x10\x05\x12\x19\n\x15THIRD_PARTY_ATTRIBUTE\x10\x06\x42j\n\x17\x63om.yoti.sharepubapi_v1B\x0e\x44\x61taEntryProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DataEntry_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\016DataEntryProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _DATAENTRY._serialized_start=61
  _DATAENTRY._serialized_end=292
  _DATAENTRY_TYPE._serialized_start=146
  _DATAENTRY_TYPE._serialized_end=292
# @@protoc_insertion_point(module_scope)
