# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ExtraData.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import DataEntry_pb2 as sharepubapi__v1_dot_DataEntry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esharepubapi_v1/ExtraData.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1esharepubapi_v1/DataEntry.proto\">\n\tExtraData\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.yoti.core.sharepubapi_v1.DataEntryBj\n\x17\x63om.yoti.sharepubapi_v1B\x0e\x45xtraDataProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ExtraData_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\016ExtraDataProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _EXTRADATA._serialized_start=92
  _EXTRADATA._serialized_end=154
# @@protoc_insertion_point(module_scope)
