# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ScanYotiCompleteShare.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2
from . import Sharing_pb2 as sharepubapi__v1_dot_Sharing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*sharepubapi_v1/ScanYotiCompleteShare.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1b\x63ompubapi_v1/Metadata.proto\x1a\x1csharepubapi_v1/Sharing.proto\"\xed\x01\n\x15ScanYotiCompleteShare\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x30\n\x06issuer\x18\x02 \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\x03 \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\tBAZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ScanYotiCompleteShare_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _SCANYOTICOMPLETESHARE._serialized_start=132
  _SCANYOTICOMPLETESHARE._serialized_end=369
# @@protoc_insertion_point(module_scope)
