# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/DocumentFields.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import MRZ_pb2 as compubapi__v1_dot_MRZ__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!compubapi_v1/DocumentFields.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a\x16\x63ompubapi_v1/MRZ.proto\"\xe4\x07\n\x0e\x44ocumentFields\x12\x11\n\tfull_name\x18\x01 \x01(\t\x12\x15\n\rdate_of_birth\x18\x02 \x01(\t\x12\x13\n\x0bnationality\x18\x03 \x01(\t\x12\x13\n\x0bgiven_names\x18\x04 \x01(\t\x12\x12\n\nfirst_name\x18\x05 \x01(\t\x12\x13\n\x0bmiddle_name\x18\x06 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x07 \x01(\t\x12\x16\n\x0eplace_of_birth\x18\x08 \x01(\t\x12\x18\n\x10\x63ountry_of_birth\x18\t \x01(\t\x12\x0e\n\x06gender\x18\n \x01(\t\x12\x13\n\x0bname_prefix\x18\x0b \x01(\t\x12\x13\n\x0bname_suffix\x18\x0c \x01(\t\x12\x18\n\x10\x66irst_name_alias\x18\r \x01(\t\x12\x19\n\x11middle_name_alias\x18\x0e \x01(\t\x12\x19\n\x11\x66\x61mily_name_alias\x18\x0f \x01(\t\x12\x0e\n\x06weight\x18\x10 \x01(\t\x12\x0e\n\x06height\x18\x11 \x01(\t\x12\x11\n\teye_color\x18\x12 \x01(\t\x12\x42\n\x19structured_postal_address\x18\x13 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\x12\x15\n\rdocument_type\x18\x14 \x01(\t\x12\x17\n\x0fissuing_country\x18\x15 \x01(\t\x12\x17\n\x0f\x64ocument_number\x18\x16 \x01(\t\x12\x17\n\x0f\x65xpiration_date\x18\x17 \x01(\t\x12\x15\n\rdate_of_issue\x18\x18 \x01(\t\x12\x19\n\x11issuing_authority\x18\x19 \x01(\t\x12(\n\x03mrz\x18\x1a \x01(\x0b\x32\x1b.yoti.core.compubapi_v1.MRZ\x12\x14\n\x0corganisation\x18\x1b \x01(\t\x12&\n\x1epersonal_identification_number\x18\x1c \x01(\t\x12\x13\n\x0bparent_name\x18\x1e \x01(\t\x12\x1d\n\x15\x64riving_licence_class\x18\x1f \x01(\t\x12(\n driving_licence_restriction_code\x18  \x01(\t\x12\x13\n\x0bprovisional\x18\" \x01(\x08\x12\x16\n\x0eplace_of_issue\x18# \x01(\t\x12 \n\x18\x64riving_licence_endorsed\x18$ \x01(\t\x12\x13\n\x0b\x63\x61rd_number\x18% \x01(\t\x12\x43\n\x11\x64ocument_template\x18& \x01(\x0b\x32(.yoti.core.compubapi_v1.DocumentTemplateJ\x04\x08\x1d\x10\x1eJ\x04\x08!\x10\"\"C\n\x10\x44ocumentTemplate\x12\x17\n\x0f\x66ront_page_name\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61\x63k_page_name\x18\x02 \x01(\t\"W\n\x16\x45xpandedDocumentFields\x12=\n\x06\x66ields\x18\x01 \x03(\x0b\x32-.yoti.core.compubapi_v1.ExpandedDocumentField\"\x86\x01\n\x15\x45xpandedDocumentField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x14\n\x0cis_non_latin\x18\x05 \x01(\x08\x12\x1a\n\x12is_transliteration\x18\x06 \x01(\x08\x42i\n\x15\x63om.yoti.compubapi_v1B\x13\x44ocumentFieldsProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DocumentFields_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\023DocumentFieldsProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _DOCUMENTFIELDS._serialized_start=114
  _DOCUMENTFIELDS._serialized_end=1110
  _DOCUMENTTEMPLATE._serialized_start=1112
  _DOCUMENTTEMPLATE._serialized_end=1179
  _EXPANDEDDOCUMENTFIELDS._serialized_start=1181
  _EXPANDEDDOCUMENTFIELDS._serialized_end=1268
  _EXPANDEDDOCUMENTFIELD._serialized_start=1271
  _EXPANDEDDOCUMENTFIELD._serialized_end=1405
# @@protoc_insertion_point(module_scope)
