# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/CancelSharing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sharepubapi_v1/CancelSharing.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1b\x63ompubapi_v1/Metadata.proto\"\xaa\x01\n\x14\x43\x61ncelSharingRequest\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\x13\n\x0bwrapped_key\x18\x03 \x01(\x0c\x12\x12\n\ncredential\x18\x04 \x01(\x0c\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\"@\n\x19\x43\x61ncelSharingNotification\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nerror_code\x18\x02 \x01(\tBn\n\x17\x63om.yoti.sharepubapi_v1B\x12\x43\x61ncelSharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CancelSharing_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\022CancelSharingProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _CANCELSHARINGREQUEST._serialized_start=94
  _CANCELSHARINGREQUEST._serialized_end=264
  _CANCELSHARINGNOTIFICATION._serialized_start=266
  _CANCELSHARINGNOTIFICATION._serialized_end=330
# @@protoc_insertion_point(module_scope)
