# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/Signing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Attribute_pb2 as attrpubapi__v1_dot_Attribute__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ttrpubapi_v1/Signing.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1d\x61ttrpubapi_v1/Attribute.proto\"\xb4\x01\n\x10\x41ttributeSigning\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12:\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32$.yoti.core.attrpubapi_v1.ContentType\x12\x1a\n\x12\x61rtifact_signature\x18\x04 \x01(\x0c\x12\x10\n\x08sub_type\x18\x05 \x01(\t\x12\x19\n\x11\x61ssociated_source\x18\x07 \x01(\tBn\n\x16\x63om.yoti.attrpubapi_v1B\x15\x41ttributeSigningProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Signing_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\025AttributeSigningProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTESIGNING._serialized_start=88
  _ATTRIBUTESIGNING._serialized_end=268
# @@protoc_insertion_point(module_scope)
