# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/Metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63ompubapi_v1/Metadata.proto\x12\x16yoti.core.compubapi_v1\"\xfb\x04\n\x08Metadata\x12\x18\n\x10manufacture_name\x18\x01 \x01(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x0f\n\x07os_name\x18\x03 \x01(\t\x12\x12\n\nos_version\x18\x04 \x01(\t\x12\x17\n\x0fos_vendor_layer\x18\x05 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x06 \x01(\t\x12\x12\n\nstart_time\x18\x07 \x01(\t\x12\x19\n\x11\x61vailable_sensors\x18\x08 \x03(\t\x12\x14\n\x0c\x64\x65mog_gender\x18\t \x01(\t\x12\x11\n\tdemog_age\x18\n \x01(\t\x12\x15\n\rdemog_country\x18\x0b \x01(\t\x12\x39\n\x07product\x18\x0c \x01(\x0e\x32(.yoti.core.compubapi_v1.Metadata.Product\x12\x14\n\x0c\x62rowser_name\x18\r \x01(\t\x12\x17\n\x0f\x62rowser_version\x18\x0e \x01(\t\x12\x0e\n\x06locale\x18\x0f \x01(\t\x12\x11\n\tstat_uuid\x18\x10 \x01(\t\x12\r\n\x05\x64\x65\x62ug\x18\x11 \x01(\t\x12\x19\n\x11\x64\x65vice_identifier\x18\x12 \x01(\t\"\xc4\x01\n\x07Product\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08YOTI_APP\x10\x01\x12\x13\n\x0fYPM_BROWSER_EXT\x10\x02\x12\r\n\tYOTI_DOCS\x10\x03\x12\x14\n\x10POSTOFFICEID_APP\x10\x04\x12\x0b\n\x07\x43ONNECT\x10\x05\x12\r\n\tYOTI_SIGN\x10\x06\x12\x07\n\x03\x41VS\x10\x07\x12\r\n\tSCAN_YOTI\x10\x08\x12\r\n\tLBGID_APP\x10\t\x12\x07\n\x03KYC\x10\n\x12\x16\n\x12\x43ONTENT_MODERATION\x10\x0b\x42T\n\x15\x63om.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Metadata_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _METADATA._serialized_start=56
  _METADATA._serialized_end=691
  _METADATA_PRODUCT._serialized_start=495
  _METADATA_PRODUCT._serialized_end=691
# @@protoc_insertion_point(module_scope)
