# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/IdentityProfilePreview.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import IdentityProfileReport_pb2 as compubapi__v1_dot_IdentityProfileReport__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)compubapi_v1/IdentityProfilePreview.proto\x12\x16yoti.core.compubapi_v1\x1a(compubapi_v1/IdentityProfileReport.proto\"\xf4\x01\n\x16IdentityProfilePreview\x12J\n\x12schemes_compliance\x18\x01 \x03(\x0b\x32..yoti.core.compubapi_v1.SchemeComplianceReport\x12H\n\x12identity_assertion\x18\x02 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityAssertionExt\x12\x44\n\x12\x63ompliance_reports\x18\x03 \x03(\x0b\x32(.yoti.core.compubapi_v1.ComplianceReportB=Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfilePreview_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _IDENTITYPROFILEPREVIEW._serialized_start=112
  _IDENTITYPROFILEPREVIEW._serialized_end=356
# @@protoc_insertion_point(module_scope)
