# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/IdentityProfileReport.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import DocumentFields_pb2 as compubapi__v1_dot_DocumentFields__pb2
from . import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2
from . import UserProfile_pb2 as compubapi__v1_dot_UserProfile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(compubapi_v1/IdentityProfileReport.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a!compubapi_v1/DocumentFields.proto\x1a\"compubapi_v1/IdentityProfile.proto\x1a\x1e\x63ompubapi_v1/UserProfile.proto\"\x87\x04\n\x15IdentityProfileReport\x12H\n\x12identity_assertion\x18\x01 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityAssertionExt\x12G\n\x13verification_report\x18\x02 \x01(\x0b\x32*.yoti.core.compubapi_v1.VerificationReport\x12,\n\x05proof\x18\x03 \x01(\x0b\x32\x1d.yoti.core.compubapi_v1.Proof\x12K\n\x15\x61uthentication_report\x18\x04 \x01(\x0b\x32,.yoti.core.compubapi_v1.AuthenticationReport\x12H\n\x14profile_match_report\x18\x05 \x01(\x0b\x32*.yoti.core.compubapi_v1.ProfileMatchReport\x12H\n\x14verification_reports\x18\x06 \x03(\x0b\x32*.yoti.core.compubapi_v1.VerificationReport\x12L\n\x16\x61uthentication_reports\x18\x07 \x03(\x0b\x32,.yoti.core.compubapi_v1.AuthenticationReport\"\xac\x01\n\x14IdentityAssertionExt\x12<\n\x0c\x63urrent_name\x18\x01 \x01(\x0b\x32&.yoti.core.compubapi_v1.StructuredName\x12\x15\n\rdate_of_birth\x18\x02 \x01(\t\x12?\n\x0f\x63urrent_address\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.CurrentAddress\"\x90\x04\n\x12VerificationReport\x12\x11\n\treport_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x12\n\nsubject_id\x18\x03 \x01(\t\x12\\\n\x14\x61\x64\x64ress_verification\x18\x04 \x01(\x0b\x32>.yoti.core.compubapi_v1.VerificationReport.AddressVerification\x12?\n\x0ftrust_framework\x18\x05 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12J\n\x12schemes_compliance\x18\x06 \x03(\x0b\x32..yoti.core.compubapi_v1.SchemeComplianceReport\x12\x43\n\x11\x61ssurance_process\x18\x07 \x01(\x0b\x32(.yoti.core.compubapi_v1.AssuranceProcess\x12?\n\x08\x65vidence\x18\x08 \x01(\x0b\x32-.yoti.core.compubapi_v1.EvidenceCollectionExt\x1aO\n\x13\x41\x64\x64ressVerification\x12 \n\x18\x63urrent_address_verified\x18\x01 \x01(\x08\x12\x16\n\x0e\x65vidence_links\x18\x02 \x03(\t\"\x8e\x01\n\x19RequirementsNotMetDetails\x12\x14\n\x0c\x66\x61ilure_type\x18\x01 \x01(\t\x12\x15\n\rdocument_type\x18\x02 \x01(\t\x12!\n\x19\x64ocument_country_iso_code\x18\x03 \x01(\t\x12\x10\n\x08\x61udit_id\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\"\xde\x01\n\x16SchemeComplianceReport\x12.\n\x06scheme\x18\x01 \x01(\x0b\x32\x1e.yoti.core.compubapi_v1.Scheme\x12\x18\n\x10requirements_met\x18\x02 \x01(\x08\x12!\n\x19requirements_not_met_info\x18\x03 \x01(\t\x12W\n\x1crequirements_not_met_details\x18\x04 \x03(\x0b\x32\x31.yoti.core.compubapi_v1.RequirementsNotMetDetails\"\x9f\x01\n\x10\x43omplianceReport\x12?\n\x0ftrust_framework\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12J\n\x12schemes_compliance\x18\x02 \x03(\x0b\x32..yoti.core.compubapi_v1.SchemeComplianceReport\"\x87\x01\n\x10\x41ssuranceProcess\x12\x1a\n\x12level_of_assurance\x18\x01 \x01(\t\x12\x0e\n\x06policy\x18\x02 \x01(\t\x12\x11\n\tprocedure\x18\x03 \x01(\t\x12\x34\n\tassurance\x18\x04 \x03(\x0b\x32!.yoti.core.compubapi_v1.Assurance\"I\n\tAssurance\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12\x16\n\x0e\x65vidence_links\x18\x03 \x03(\t\"\xe6\x01\n\x15\x45videnceCollectionExt\x12<\n\x04\x66\x61\x63\x65\x18\x01 \x01(\x0b\x32..yoti.core.compubapi_v1.FaceCaptureEvidenceExt\x12>\n\tdocuments\x18\x02 \x03(\x0b\x32+.yoti.core.compubapi_v1.DocumentEvidenceExt\x12O\n\x12\x65lectronic_records\x18\x03 \x03(\x0b\x32\x33.yoti.core.compubapi_v1.ElectronicRecordEvidenceExt\"\xae\x02\n\x16\x46\x61\x63\x65\x43\x61ptureEvidenceExt\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12@\n\x10initial_liveness\x18\x02 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x45\n\x15last_matched_liveness\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x15\n\rverifying_org\x18\x04 \x01(\t\x12\x14\n\x0cresource_ids\x18\x05 \x03(\t\x12\x11\n\tcheck_ids\x18\x06 \x03(\t\x12\x19\n\x11user_activity_ids\x18\x07 \x03(\t\x12\x1b\n\x13selfie_attribute_id\x18\x08 \x01(\t\"\xbd\x02\n\x13\x44ocumentEvidenceExt\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12?\n\x0f\x64ocument_fields\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.DocumentFields\x12<\n\rpassed_checks\x18\x04 \x03(\x0b\x32%.yoti.core.compubapi_v1.DocumentCheck\x12$\n\x1c\x64ocument_images_attribute_id\x18\x05 \x01(\t\x12\x15\n\rverifying_org\x18\x06 \x01(\t\x12\x14\n\x0cresource_ids\x18\x07 \x03(\t\x12\x11\n\tcheck_ids\x18\x08 \x03(\t\x12\x19\n\x11user_activity_ids\x18\t \x03(\t\"\xf9\x01\n\x1b\x45lectronicRecordEvidenceExt\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x41\n\x10identity_details\x18\x03 \x01(\x0b\x32\'.yoti.core.compubapi_v1.IdentityDetails\x12\x15\n\rverifying_org\x18\x04 \x01(\t\x12\x14\n\x0cprovider_org\x18\x05 \x01(\t\x12\x14\n\x0cresource_ids\x18\x06 \x03(\t\x12\x11\n\tcheck_ids\x18\x07 \x03(\t\x12\x19\n\x11user_activity_ids\x18\x08 \x03(\t\"S\n\x0e\x43urrentAddress\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\x12\x0f\n\x07move_in\x18\x02 \x01(\t\"\x9c\x01\n\x14\x41uthenticationReport\x12\x11\n\treport_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0e\n\x06policy\x18\x04 \x01(\t\x12?\n\x0ftrust_framework\x18\x05 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\",\n\x05Proof\x12\x0b\n\x03jws\x18\x01 \x01(\t\x12\x16\n\x0epublic_key_url\x18\x02 \x01(\t\"\x94\x01\n\x11MatchReportResult\x12@\n\x06result\x18\x01 \x01(\x0e\x32\x30.yoti.core.compubapi_v1.MatchReportResult.Result\"=\n\x06Result\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08NO_MATCH\x10\x01\x12\t\n\x05MATCH\x10\x02\x12\x0b\n\x07PARTIAL\x10\x03\"\x89\x02\n\x12ProfileMatchReport\x12\x46\n\x10provided_profile\x18\x01 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityAssertionExt\x12\x37\n\x04name\x18\x02 \x01(\x0b\x32).yoti.core.compubapi_v1.MatchReportResult\x12\x36\n\x03\x64ob\x18\x03 \x01(\x0b\x32).yoti.core.compubapi_v1.MatchReportResult\x12:\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32).yoti.core.compubapi_v1.MatchReportResultBp\n\x15\x63om.yoti.compubapi_v1B\x1aIdentityProfileReportProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfileReport_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\032IdentityProfileReportProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _IDENTITYPROFILEREPORT._serialized_start=200
  _IDENTITYPROFILEREPORT._serialized_end=719
  _IDENTITYASSERTIONEXT._serialized_start=722
  _IDENTITYASSERTIONEXT._serialized_end=894
  _VERIFICATIONREPORT._serialized_start=897
  _VERIFICATIONREPORT._serialized_end=1425
  _VERIFICATIONREPORT_ADDRESSVERIFICATION._serialized_start=1346
  _VERIFICATIONREPORT_ADDRESSVERIFICATION._serialized_end=1425
  _REQUIREMENTSNOTMETDETAILS._serialized_start=1428
  _REQUIREMENTSNOTMETDETAILS._serialized_end=1570
  _SCHEMECOMPLIANCEREPORT._serialized_start=1573
  _SCHEMECOMPLIANCEREPORT._serialized_end=1795
  _COMPLIANCEREPORT._serialized_start=1798
  _COMPLIANCEREPORT._serialized_end=1957
  _ASSURANCEPROCESS._serialized_start=1960
  _ASSURANCEPROCESS._serialized_end=2095
  _ASSURANCE._serialized_start=2097
  _ASSURANCE._serialized_end=2170
  _EVIDENCECOLLECTIONEXT._serialized_start=2173
  _EVIDENCECOLLECTIONEXT._serialized_end=2403
  _FACECAPTUREEVIDENCEEXT._serialized_start=2406
  _FACECAPTUREEVIDENCEEXT._serialized_end=2708
  _DOCUMENTEVIDENCEEXT._serialized_start=2711
  _DOCUMENTEVIDENCEEXT._serialized_end=3028
  _ELECTRONICRECORDEVIDENCEEXT._serialized_start=3031
  _ELECTRONICRECORDEVIDENCEEXT._serialized_end=3280
  _CURRENTADDRESS._serialized_start=3282
  _CURRENTADDRESS._serialized_end=3365
  _AUTHENTICATIONREPORT._serialized_start=3368
  _AUTHENTICATIONREPORT._serialized_end=3524
  _PROOF._serialized_start=3526
  _PROOF._serialized_end=3570
  _MATCHREPORTRESULT._serialized_start=3573
  _MATCHREPORTRESULT._serialized_end=3721
  _MATCHREPORTRESULT_RESULT._serialized_start=3660
  _MATCHREPORTRESULT_RESULT._serialized_end=3721
  _PROFILEMATCHREPORT._serialized_start=3724
  _PROFILEMATCHREPORT._serialized_end=3989
# @@protoc_insertion_point(module_scope)
