# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ThirdPartyAttribute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import IssuingAttributes_pb2 as sharepubapi__v1_dot_IssuingAttributes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(sharepubapi_v1/ThirdPartyAttribute.proto\x12\x18yoti.core.sharepubapi_v1\x1a&sharepubapi_v1/IssuingAttributes.proto\"v\n\x13ThirdPartyAttribute\x12\x16\n\x0eissuance_token\x18\x01 \x01(\x0c\x12G\n\x12issuing_attributes\x18\x02 \x01(\x0b\x32+.yoti.core.sharepubapi_v1.IssuingAttributesBt\n\x17\x63om.yoti.sharepubapi_v1B\x18ThirdPartyAttributeProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ThirdPartyAttribute_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\030ThirdPartyAttributeProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _THIRDPARTYATTRIBUTE._serialized_start=110
  _THIRDPARTYATTRIBUTE._serialized_end=228
# @@protoc_insertion_point(module_scope)
