# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/ChipInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63ompubapi_v1/ChipInfo.proto\x12\x0c\x63ompubapi_v1\"d\n\x08\x43hipInfo\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.compubapi_v1.ChipInfo.Type\x12\n\n\x02id\x18\x02 \x01(\t\"!\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06MULTOS\x10\x01\x42T\n\x15\x63om.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChipInfo_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _CHIPINFO._serialized_start=45
  _CHIPINFO._serialized_end=145
  _CHIPINFO_TYPE._serialized_start=112
  _CHIPINFO_TYPE._serialized_end=145
# @@protoc_insertion_point(module_scope)
