# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/List.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Attribute_pb2 as attrpubapi__v1_dot_Attribute__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ttrpubapi_v1/List.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1d\x61ttrpubapi_v1/Attribute.proto\"]\n\x0e\x41ttributeAndId\x12\x35\n\tattribute\x18\x01 \x01(\x0b\x32\".yoti.core.attrpubapi_v1.Attribute\x12\x14\n\x0c\x61ttribute_id\x18\x02 \x01(\x0c\"\\\n\x12\x41ttributeAndIdList\x12\x46\n\x15\x61ttribute_and_id_list\x18\x01 \x03(\x0b\x32\'.yoti.core.attrpubapi_v1.AttributeAndId\"G\n\rAttributeList\x12\x36\n\nattributes\x18\x01 \x03(\x0b\x32\".yoti.core.attrpubapi_v1.AttributeBk\n\x16\x63om.yoti.attrpubapi_v1B\x12\x41ttributeListProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'List_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\022AttributeListProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTEANDID._serialized_start=84
  _ATTRIBUTEANDID._serialized_end=177
  _ATTRIBUTEANDIDLIST._serialized_start=179
  _ATTRIBUTEANDIDLIST._serialized_end=271
  _ATTRIBUTELIST._serialized_start=273
  _ATTRIBUTELIST._serialized_end=344
# @@protoc_insertion_point(module_scope)
