# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/AttributeChange.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Refresh_pb2 as attrpubapi__v1_dot_Refresh__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#attrpubapi_v1/AttributeChange.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1b\x61ttrpubapi_v1/Refresh.proto\"j\n\x0f\x41ttributeChange\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.yoti.core.attrpubapi_v1.RefreshResponse.Status\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\tBm\n\x16\x63om.yoti.attrpubapi_v1B\x14\x41ttributeChangeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AttributeChange_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\024AttributeChangeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTECHANGE._serialized_start=93
  _ATTRIBUTECHANGE._serialized_end=199
# @@protoc_insertion_point(module_scope)
