# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/Policy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsharepubapi_v1/Policy.proto\x12\x18yoti.core.sharepubapi_v1\x1a\"compubapi_v1/IdentityProfile.proto\"\x83\x0c\n\x06Policy\x12:\n\x06wanted\x18\x01 \x03(\x0b\x32*.yoti.core.sharepubapi_v1.Policy.Attribute\x12\x39\n\x05given\x18\x02 \x03(\x0b\x32*.yoti.core.sharepubapi_v1.Policy.Attribute\x12\x1a\n\x12wanted_remember_me\x18\x03 \x01(\x08\x12\x19\n\x11given_remember_me\x18\x04 \x01(\x08\x12\x18\n\x10given_auth_types\x18\x05 \x03(\x05\x12\x19\n\x11wanted_auth_types\x18\x06 \x03(\x05\x12#\n\x1bwanted_remember_me_optional\x18\x07 \x01(\x08\x12M\n\x10identity_profile\x18\x08 \x01(\x0b\x32\x33.yoti.core.compubapi_v1.IdentityProfileRequirements\x12S\n\x13verification_report\x18\t \x01(\x0b\x32\x36.yoti.core.compubapi_v1.VerificationReportRequirements\x12^\n\x19\x61\x64vanced_identity_profile\x18\x0b \x01(\x0b\x32;.yoti.core.compubapi_v1.AdvancedIdentityProfileRequirements\x1a\x8e\x01\n\nConstraint\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.yoti.core.sharepubapi_v1.Policy.Constraint.Type\x12\x12\n\nconstraint\x18\x02 \x01(\x0c\",\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05VALUE\x10\x01\x12\n\n\x06SOURCE\x10\x02\x1a\x8b\x01\n\x0fValueConstraint\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.yoti.core.sharepubapi_v1.Policy.ValueConstraint.Type\x12\x12\n\nconstraint\x18\x02 \x01(\x0c\"\x1f\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04\x44\x41TE\x10\x01\x1a\xde\x01\n\x0e\x44\x61teConstraint\x12\x44\n\x02op\x18\x01 \x01(\x0e\x32\x38.yoti.core.sharepubapi_v1.Policy.DateConstraint.Operator\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\t\x12;\n\x06offset\x18\x03 \x01(\x0b\x32+.yoti.core.sharepubapi_v1.Policy.DateOffset\";\n\x08Operator\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06\x42\x45\x46ORE\x10\x01\x12\t\n\x05\x41\x46TER\x10\x02\x12\t\n\x05\x45QUAL\x10\x03\x1a*\n\nDateOffset\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x05\x12\x0e\n\x06months\x18\x02 \x01(\x05\x1a(\n\x06\x41nchor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sub_type\x18\x02 \x01(\t\x1a\x63\n\x0ePreferenceList\x12\x38\n\x07\x61nchors\x18\x01 \x03(\x0b\x32\'.yoti.core.sharepubapi_v1.Policy.Anchor\x12\x17\n\x0fsoft_preference\x18\x02 \x01(\x08\x1a^\n\x10SourceConstraint\x12J\n\x11preferred_sources\x18\x01 \x01(\x0b\x32/.yoti.core.sharepubapi_v1.Policy.PreferenceList\x1a\xcb\x01\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61nchors\x18\x02 \x03(\t\x12\x12\n\nderivation\x18\x03 \x01(\t\x12\x10\n\x08optional\x18\x04 \x01(\x08\x12\x1c\n\x14\x61\x63\x63\x65pt_self_asserted\x18\x05 \x01(\x08\x12@\n\x0b\x63onstraints\x18\x06 \x03(\x0b\x32+.yoti.core.sharepubapi_v1.Policy.Constraint\x12\x19\n\x11\x61lternative_names\x18\x07 \x03(\tJ\x04\x08\n\x10\x0b\x42g\n\x17\x63om.yoti.sharepubapi_v1B\x0bPolicyProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Policy_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\013PolicyProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _POLICY._serialized_start=94
  _POLICY._serialized_end=1633
  _POLICY_CONSTRAINT._serialized_start=629
  _POLICY_CONSTRAINT._serialized_end=771
  _POLICY_CONSTRAINT_TYPE._serialized_start=727
  _POLICY_CONSTRAINT_TYPE._serialized_end=771
  _POLICY_VALUECONSTRAINT._serialized_start=774
  _POLICY_VALUECONSTRAINT._serialized_end=913
  _POLICY_VALUECONSTRAINT_TYPE._serialized_start=882
  _POLICY_VALUECONSTRAINT_TYPE._serialized_end=913
  _POLICY_DATECONSTRAINT._serialized_start=916
  _POLICY_DATECONSTRAINT._serialized_end=1138
  _POLICY_DATECONSTRAINT_OPERATOR._serialized_start=1079
  _POLICY_DATECONSTRAINT_OPERATOR._serialized_end=1138
  _POLICY_DATEOFFSET._serialized_start=1140
  _POLICY_DATEOFFSET._serialized_end=1182
  _POLICY_ANCHOR._serialized_start=1184
  _POLICY_ANCHOR._serialized_end=1224
  _POLICY_PREFERENCELIST._serialized_start=1226
  _POLICY_PREFERENCELIST._serialized_end=1325
  _POLICY_SOURCECONSTRAINT._serialized_start=1327
  _POLICY_SOURCECONSTRAINT._serialized_end=1421
  _POLICY_ATTRIBUTE._serialized_start=1424
  _POLICY_ATTRIBUTE._serialized_end=1627
# @@protoc_insertion_point(module_scope)
