# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/SharingNotificationPush.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Policy_pb2 as sharepubapi__v1_dot_Policy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sharepubapi_v1/SharingNotificationPush.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1bsharepubapi_v1/Policy.proto\"\x90\x01\n\x13SharingNotification\x12\x15\n\rsharing_token\x18\x01 \x01(\x0c\x12\x1a\n\x12notification_token\x18\x02 \x01(\x0c\x12\x14\n\x0csession_data\x18\x03 \x01(\t\x12\x30\n\x06policy\x18\x04 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.PolicyBt\n\x17\x63om.yoti.sharepubapi_v1B\x18SharingNotificationProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SharingNotificationPush_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\030SharingNotificationProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _SHARINGNOTIFICATION._serialized_start=104
  _SHARINGNOTIFICATION._serialized_end=248
# @@protoc_insertion_point(module_scope)
