# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/MRZ.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ompubapi_v1/MRZ.proto\x12\x16yoti.core.compubapi_v1\"\x92\x01\n\x03MRZ\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\r\n\x05line1\x18\x02 \x01(\t\x12\r\n\x05line2\x18\x03 \x01(\t\x12\r\n\x05line3\x18\x04 \x01(\t\"P\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03TD1\x10\x01\x12\x07\n\x03TD3\x10\x02\x12\n\n\x06RUS_ID\x10\x03\x12\x07\n\x03TD2\x10\x04\x12\x12\n\rUNCATEGORISED\x10\xe8\x07\x42T\n\x15\x63om.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MRZ_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1Z,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _MRZ._serialized_start=51
  _MRZ._serialized_end=197
  _MRZ_TYPE._serialized_start=117
  _MRZ_TYPE._serialized_end=197
# @@protoc_insertion_point(module_scope)
