# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/RsaAuthDigest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Signature_pb2 as compubapi__v1_dot_Signature__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n compubapi_v1/RsaAuthDigest.proto\x12\x16yoti.core.compubapi_v1\x1a\x1c\x63ompubapi_v1/Signature.proto\"x\n\rRsaAuthDigest\x12\x0f\n\x07pub_key\x18\x01 \x01(\x0c\x12\r\n\x05nonce\x18\x02 \x01(\x0c\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x34\n\tsignature\x18\x04 \x01(\x0b\x32!.yoti.core.compubapi_v1.SignatureBh\n\x15\x63om.yoti.compubapi_v1B\x12RsaAuthDigestProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RsaAuthDigest_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\022RsaAuthDigestProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _RSAAUTHDIGEST._serialized_start=90
  _RSAAUTHDIGEST._serialized_end=210
# @@protoc_insertion_point(module_scope)
