# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/IssuingAttributes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sharepubapi_v1/IssuingAttributes.proto\x12\x18yoti.core.sharepubapi_v1\"c\n\x11IssuingAttributes\x12\x13\n\x0b\x65xpiry_date\x18\x01 \x01(\t\x12\x39\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32$.yoti.core.sharepubapi_v1.Definition\"\x1a\n\nDefinition\x12\x0c\n\x04name\x18\x01 \x01(\tBr\n\x17\x63om.yoti.sharepubapi_v1B\x16IssuingAttributesProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IssuingAttributes_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\026IssuingAttributesProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _ISSUINGATTRIBUTES._serialized_start=68
  _ISSUINGATTRIBUTES._serialized_end=167
  _DEFINITION._serialized_start=169
  _DEFINITION._serialized_end=195
# @@protoc_insertion_point(module_scope)
