# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/UserProfile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import IdentityProfile_pb2 as compubapi__v1_dot_IdentityProfile__pb2
from . import DocumentFields_pb2 as compubapi__v1_dot_DocumentFields__pb2
from . import DocumentTypes_pb2 as compubapi__v1_dot_DocumentTypes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ompubapi_v1/UserProfile.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a\"compubapi_v1/IdentityProfile.proto\x1a!compubapi_v1/DocumentFields.proto\x1a compubapi_v1/DocumentTypes.proto\"\xbc\x01\n\x0bUserProfile\x12\x45\n\x12identity_assertion\x18\x01 \x01(\x0b\x32).yoti.core.compubapi_v1.IdentityAssertion\x12!\n\x19\x65vidence_collection_db_id\x18\x02 \x01(\x0c\x12\x43\n\x11unlinked_evidence\x18\x03 \x03(\x0b\x32(.yoti.core.compubapi_v1.UnlinkedEvidence\"\xc2\x02\n\x11IdentityAssertion\x12\x32\n\x0c\x63urrent_name\x18\x01 \x01(\x0b\x32\x1c.yoti.core.compubapi_v1.Name\x12:\n\rdate_of_birth\x18\x02 \x01(\x0b\x32#.yoti.core.compubapi_v1.DateOfBirth\x12\x41\n\x0f\x63urrent_address\x18\x03 \x01(\x0b\x32(.yoti.core.compubapi_v1.AddressWithDates\x12\x44\n\x12previous_addresses\x18\x04 \x03(\x0b\x32(.yoti.core.compubapi_v1.AddressWithDates\x12\x34\n\x0eprevious_names\x18\x05 \x03(\x0b\x32\x1c.yoti.core.compubapi_v1.Name\"\x82\x03\n\x10\x41\x64\x64ressWithDates\x12\x38\n\x0fprofile_address\x18\x01 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\x12\x0f\n\x07move_in\x18\x02 \x01(\t\x12\x10\n\x08move_out\x18\x03 \x01(\t\x12<\n\x0e\x65vidence_links\x18\x04 \x03(\x0b\x32$.yoti.core.compubapi_v1.EvidenceLink\x12<\n\x08\x61\x64\x64\x65\x64_at\x18\x07 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12@\n\x0c\x63onfirmed_at\x18\x08 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12\x41\n\rconfirmations\x18\t \x03(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestampJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\n\x10\x0b\"\xac\x01\n\x12\x41ssertionTimestamp\x12\n\n\x02ts\x18\x01 \x01(\t\x12\x41\n\x06source\x18\x02 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.AssertionTimestamp.Source\"G\n\x06Source\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08\x44OCUMENT\x10\x01\x12\n\n\x06MANUAL\x10\x02\x12\x14\n\x10RELYING_BUSINESS\x10\x03\"\xd3\x02\n\x12\x43onfirmationStatus\x12\x41\n\x06source\x18\x01 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.ConfirmationStatus.Source\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.ConfirmationStatus.Status\";\n\x06Source\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08\x45ND_USER\x10\x01\x12\x14\n\x10RELYING_BUSINESS\x10\x02\"g\n\x06Status\x12\x1a\n\x16NO_MANUAL_CONFIRMATION\x10\x00\x12!\n\x1dMANUAL_CONFIRMATION_SUCCEEDED\x10\x01\x12\x1e\n\x1aMANUAL_CONFIRMATION_FAILED\x10\x02\"\xef\x02\n\x04Name\x12\x34\n\x04name\x18\x01 \x01(\x0b\x32&.yoti.core.compubapi_v1.StructuredName\x12\x11\n\theld_from\x18\x02 \x01(\t\x12\x0f\n\x07held_to\x18\x03 \x01(\t\x12<\n\x0e\x65vidence_links\x18\x04 \x03(\x0b\x32$.yoti.core.compubapi_v1.EvidenceLink\x12<\n\x08\x61\x64\x64\x65\x64_at\x18\x05 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12\x41\n\rconfirmations\x18\x06 \x03(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12N\n\x1amanual_confirmation_status\x18\x07 \x01(\x0b\x32*.yoti.core.compubapi_v1.ConfirmationStatus\"\xb3\x02\n\x0b\x44\x61teOfBirth\x12\x15\n\rdate_of_birth\x18\x01 \x01(\t\x12<\n\x0e\x65vidence_links\x18\x02 \x03(\x0b\x32$.yoti.core.compubapi_v1.EvidenceLink\x12<\n\x08\x61\x64\x64\x65\x64_at\x18\x03 \x01(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12\x41\n\rconfirmations\x18\x04 \x03(\x0b\x32*.yoti.core.compubapi_v1.AssertionTimestamp\x12N\n\x1amanual_confirmation_status\x18\x05 \x01(\x0b\x32*.yoti.core.compubapi_v1.ConfirmationStatus\"v\n\x0eStructuredName\x12\x13\n\x0bgiven_names\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x13\n\x0bmiddle_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x11\n\tfull_name\x18\x05 \x01(\t\"#\n\x0c\x45videnceLink\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\"\xda\x01\n\x12\x45videnceCollection\x12\x39\n\x04\x66\x61\x63\x65\x18\x01 \x01(\x0b\x32+.yoti.core.compubapi_v1.FaceCaptureEvidence\x12;\n\tdocuments\x18\x02 \x03(\x0b\x32(.yoti.core.compubapi_v1.DocumentEvidence\x12L\n\x12\x65lectronic_records\x18\x03 \x03(\x0b\x32\x30.yoti.core.compubapi_v1.ElectronicRecordEvidence\"\xd7\x02\n\x13\x46\x61\x63\x65\x43\x61ptureEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x36\n\x0b\x61udit_links\x18\x02 \x03(\x0b\x32!.yoti.core.compubapi_v1.AuditLink\x12@\n\x10initial_liveness\x18\x03 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x45\n\x15last_matched_liveness\x18\x04 \x01(\x0b\x32&.yoti.core.compubapi_v1.PassedLiveness\x12\x36\n\x06source\x18\x05 \x01(\x0b\x32&.yoti.core.compubapi_v1.EvidenceSource\x12\x15\n\rverifying_org\x18\x06 \x01(\t\x12\x1b\n\x13selfie_attribute_id\x18\x07 \x01(\x0c\"\xe0\x03\n\x10\x44ocumentEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x36\n\x0b\x61udit_links\x18\x03 \x03(\x0b\x32!.yoti.core.compubapi_v1.AuditLink\x12\x39\n\rdocument_info\x18\x04 \x01(\x0b\x32\".yoti.core.compubapi_v1.IdDocument\x12?\n\x0f\x64ocument_fields\x18\x05 \x01(\x0b\x32&.yoti.core.compubapi_v1.DocumentFields\x12<\n\rpassed_checks\x18\x06 \x03(\x0b\x32%.yoti.core.compubapi_v1.DocumentCheck\x12$\n\x1c\x64ocument_images_attribute_id\x18\x07 \x01(\x0c\x12\x36\n\x06source\x18\x08 \x01(\x0b\x32&.yoti.core.compubapi_v1.EvidenceSource\x12\x15\n\rverifying_org\x18\t \x01(\t\x12=\n\x0eimport_details\x18\n \x01(\x0b\x32%.yoti.core.compubapi_v1.ImportDetails\"\xb8\x02\n\x18\x45lectronicRecordEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x36\n\x0b\x61udit_links\x18\x03 \x03(\x0b\x32!.yoti.core.compubapi_v1.AuditLink\x12\x41\n\x10identity_details\x18\x04 \x01(\x0b\x32\'.yoti.core.compubapi_v1.IdentityDetails\x12\x15\n\rverifying_org\x18\x05 \x01(\t\x12\x14\n\x0cprovider_org\x18\x06 \x01(\t\x12L\n\x16identity_check_outcome\x18\x07 \x01(\x0b\x32,.yoti.core.compubapi_v1.IdentityCheckOutcome\"\xcc\x02\n\x14IdentityCheckOutcome\x12?\n\x04type\x18\x01 \x01(\x0e\x32\x31.yoti.core.compubapi_v1.IdentityCheckOutcome.Type\x12;\n\rcifas_outcome\x18\x02 \x01(\x0b\x32$.yoti.core.compubapi_v1.CIFASOutcome\x12\x37\n\x0b\x63ra_outcome\x18\x03 \x01(\x0b\x32\".yoti.core.compubapi_v1.CRAOutcome\x12\x43\n\x11synectics_outcome\x18\x04 \x01(\x0b\x32(.yoti.core.compubapi_v1.SynecticsOutcome\"8\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05\x43IFAS\x10\x01\x12\x07\n\x03\x43RA\x10\x02\x12\r\n\tSYNECTICS\x10\x03\"\xa0\x01\n\x0c\x43IFASOutcome\x12\x39\n\x05state\x18\x01 \x01(\x0e\x32*.yoti.core.compubapi_v1.CIFASOutcome.State\"U\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x11\n\rNOT_FRAUDSTER\x10\x01\x12\r\n\tFRAUDSTER\x10\x02\x12\x10\n\x0c\x46RAUD_VICTIM\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"\xbd\x04\n\nCRAOutcome\x12?\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0e\x32..yoti.core.compubapi_v1.CRAOutcome.MatchResult\x12<\n\x04name\x18\x02 \x01(\x0e\x32..yoti.core.compubapi_v1.CRAOutcome.MatchResult\x12;\n\x03\x64ob\x18\x03 \x01(\x0e\x32..yoti.core.compubapi_v1.CRAOutcome.MatchResult\x12G\n\x0bpep_warning\x18\x04 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.CRAOutcome.AdditionalCheck\x12\x44\n\x08\x64\x65\x63\x65\x61sed\x18\x05 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.CRAOutcome.AdditionalCheck\x12J\n\x0e\x65lectoral_roll\x18\x06 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.CRAOutcome.AdditionalCheck\x12\x19\n\x11unable_to_perform\x18\x07 \x01(\x08\">\n\x0bMatchResult\x12\x11\n\rNOT_AVAILABLE\x10\x00\x12\x0b\n\x07MATCHED\x10\x01\x12\x0f\n\x0bNOT_MATCHED\x10\x02\"=\n\x0f\x41\x64\x64itionalCheck\x12\x12\n\x0eNOT_APPLICABLE\x10\x00\x12\n\n\x06PASSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"v\n\x10SynecticsOutcome\x12\x18\n\x10\x61\x63tivity_history\x18\x01 \x01(\x05\x12\x16\n\x0eidentity_fraud\x18\x02 \x01(\x05\x12\x15\n\rfailed_checks\x18\x03 \x03(\t\x12\x19\n\x11unable_to_perform\x18\x04 \x01(\x08\"\xa8\x01\n\x0ePassedLiveness\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.yoti.core.compubapi_v1.PassedLiveness.Type\x12\x11\n\ttimestamp\x18\x02 \x01(\t\"H\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04ZOOM\x10\x01\x12\n\n\x06STATIC\x10\x02\x12\x0f\n\x0bTHREE_WORDS\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\"\xae\x01\n\tAuditLink\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.AuditLink.Type\x12\n\n\x02id\x18\x02 \x01(\t\"_\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12!\n\x1d\x44ID_USER_ACTIVITY_TRACKING_ID\x10\x01\x12\x10\n\x0cIDV_CHECK_ID\x10\x02\x12\x13\n\x0fIDV_RESOURCE_ID\x10\x03\"\x95\x01\n\x0e\x45videnceSource\x12=\n\x06source\x18\x01 \x01(\x0e\x32-.yoti.core.compubapi_v1.EvidenceSource.Source\"D\n\x06Source\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07IDV_WEB\x10\x01\x12\x11\n\rIDV_WEB_SICAP\x10\x02\x12\x0b\n\x07\x44ID_APP\x10\x03\"\xfb\x02\n\rDocumentCheck\x12:\n\x05\x63heck\x18\x01 \x01(\x0e\x32+.yoti.core.compubapi_v1.DocumentCheck.Check\"\xad\x02\n\x05\x43heck\x12\r\n\tUNDEFINED\x10\x00\x12\'\n#MANUAL_VISUAL_DOCUMENT_AUTHENTICITY\x10\x01\x12\x1a\n\x16\x43HIP_DIGITAL_SIGNATURE\x10\x02\x12\x15\n\x11ISSUING_AUTHORITY\x10\x03\x12\x14\n\x10\x44OCUMENT_IN_DATE\x10\x04\x12\x18\n\x14\x46RAUD_DOCUMENTS_LIST\x10\x05\x12\x15\n\x11MANUAL_FACE_MATCH\x10\x06\x12\x18\n\x14\x41UTOMATED_FACE_MATCH\x10\x07\x12)\n%AUTOMATED_FACE_MATCH_HIGHER_THRESHOLD\x10\x08\x12-\n)HIGH_ASSURANCE_AUTO_DOCUMENT_AUTHENTICITY\x10\t\"4\n\rImportDetails\x12\x13\n\x0bimported_at\x18\x01 \x01(\t\x12\x0e\n\x06org_id\x18\x02 \x01(\t\"\xbd\x01\n\x10UnlinkedEvidence\x12\x13\n\x0b\x65vidence_id\x18\x01 \x01(\t\x12?\n\x06reason\x18\x02 \x01(\x0e\x32/.yoti.core.compubapi_v1.UnlinkedEvidence.Reason\"S\n\x06Reason\x12\r\n\tUNDEFINED\x10\x00\x12\x11\n\rNAME_MISMATCH\x10\x01\x12\x10\n\x0c\x44OB_MISMATCH\x10\x02\x12\x15\n\x11NAME_DOB_MISMATCH\x10\x03\x42\x66\n\x15\x63om.yoti.compubapi_v1B\x10UserProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserProfile_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\020UserProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _USERPROFILE._serialized_start=192
  _USERPROFILE._serialized_end=380
  _IDENTITYASSERTION._serialized_start=383
  _IDENTITYASSERTION._serialized_end=705
  _ADDRESSWITHDATES._serialized_start=708
  _ADDRESSWITHDATES._serialized_end=1094
  _ASSERTIONTIMESTAMP._serialized_start=1097
  _ASSERTIONTIMESTAMP._serialized_end=1269
  _ASSERTIONTIMESTAMP_SOURCE._serialized_start=1198
  _ASSERTIONTIMESTAMP_SOURCE._serialized_end=1269
  _CONFIRMATIONSTATUS._serialized_start=1272
  _CONFIRMATIONSTATUS._serialized_end=1611
  _CONFIRMATIONSTATUS_SOURCE._serialized_start=1447
  _CONFIRMATIONSTATUS_SOURCE._serialized_end=1506
  _CONFIRMATIONSTATUS_STATUS._serialized_start=1508
  _CONFIRMATIONSTATUS_STATUS._serialized_end=1611
  _NAME._serialized_start=1614
  _NAME._serialized_end=1981
  _DATEOFBIRTH._serialized_start=1984
  _DATEOFBIRTH._serialized_end=2291
  _STRUCTUREDNAME._serialized_start=2293
  _STRUCTUREDNAME._serialized_end=2411
  _EVIDENCELINK._serialized_start=2413
  _EVIDENCELINK._serialized_end=2448
  _EVIDENCECOLLECTION._serialized_start=2451
  _EVIDENCECOLLECTION._serialized_end=2669
  _FACECAPTUREEVIDENCE._serialized_start=2672
  _FACECAPTUREEVIDENCE._serialized_end=3015
  _DOCUMENTEVIDENCE._serialized_start=3018
  _DOCUMENTEVIDENCE._serialized_end=3498
  _ELECTRONICRECORDEVIDENCE._serialized_start=3501
  _ELECTRONICRECORDEVIDENCE._serialized_end=3813
  _IDENTITYCHECKOUTCOME._serialized_start=3816
  _IDENTITYCHECKOUTCOME._serialized_end=4148
  _IDENTITYCHECKOUTCOME_TYPE._serialized_start=4092
  _IDENTITYCHECKOUTCOME_TYPE._serialized_end=4148
  _CIFASOUTCOME._serialized_start=4151
  _CIFASOUTCOME._serialized_end=4311
  _CIFASOUTCOME_STATE._serialized_start=4226
  _CIFASOUTCOME_STATE._serialized_end=4311
  _CRAOUTCOME._serialized_start=4314
  _CRAOUTCOME._serialized_end=4887
  _CRAOUTCOME_MATCHRESULT._serialized_start=4762
  _CRAOUTCOME_MATCHRESULT._serialized_end=4824
  _CRAOUTCOME_ADDITIONALCHECK._serialized_start=4826
  _CRAOUTCOME_ADDITIONALCHECK._serialized_end=4887
  _SYNECTICSOUTCOME._serialized_start=4889
  _SYNECTICSOUTCOME._serialized_end=5007
  _PASSEDLIVENESS._serialized_start=5010
  _PASSEDLIVENESS._serialized_end=5178
  _PASSEDLIVENESS_TYPE._serialized_start=5106
  _PASSEDLIVENESS_TYPE._serialized_end=5178
  _AUDITLINK._serialized_start=5181
  _AUDITLINK._serialized_end=5355
  _AUDITLINK_TYPE._serialized_start=5260
  _AUDITLINK_TYPE._serialized_end=5355
  _EVIDENCESOURCE._serialized_start=5358
  _EVIDENCESOURCE._serialized_end=5507
  _EVIDENCESOURCE_SOURCE._serialized_start=5439
  _EVIDENCESOURCE_SOURCE._serialized_end=5507
  _DOCUMENTCHECK._serialized_start=5510
  _DOCUMENTCHECK._serialized_end=5889
  _DOCUMENTCHECK_CHECK._serialized_start=5588
  _DOCUMENTCHECK_CHECK._serialized_end=5889
  _IMPORTDETAILS._serialized_start=5891
  _IMPORTDETAILS._serialized_end=5943
  _UNLINKEDEVIDENCE._serialized_start=5946
  _UNLINKEDEVIDENCE._serialized_end=6135
  _UNLINKEDEVIDENCE_REASON._serialized_start=6052
  _UNLINKEDEVIDENCE_REASON._serialized_end=6135
# @@protoc_insertion_point(module_scope)
