# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/ReceiptPush.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Sharing_pb2 as sharepubapi__v1_dot_Sharing__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import IdentityProfileReport_pb2 as compubapi__v1_dot_IdentityProfileReport__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sharepubapi_v1/ReceiptPush.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1csharepubapi_v1/Sharing.proto\x1a(compubapi_v1/IdentityProfileReport.proto\"\x9f\x03\n\x0eSuccessReceipt\x12\x12\n\nreceipt_id\x18\x01 \x01(\x0c\x12\x1f\n\x17other_party_profile_uri\x18\x02 \x01(\t\x12\x13\n\x0bprofile_uri\x18\x03 \x01(\t\x12\"\n\x1aother_party_extra_data_uri\x18\x04 \x01(\t\x12\x16\n\x0e\x65xtra_data_uri\x18\x05 \x01(\t\x12\x13\n\x0breceipt_key\x18\x06 \x01(\x0c\x12\x12\n\npolicy_uri\x18\x07 \x01(\t\x12\x14\n\x0cpersonal_key\x18\x08 \x01(\x0c\x12\x16\n\x0eremember_me_id\x18\t \x01(\x0c\x12\x11\n\ttimestamp\x18\n \x01(\t\x12\x14\n\x0csession_data\x18\x0b \x01(\t\x12\x30\n\x06issuer\x18\x0c \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\r \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12\x1d\n\x15parent_remember_me_id\x18\x0e \x01(\x0c\"\x93\x02\n\x0e\x46\x61ilureReceipt\x12\x12\n\nreceipt_id\x18\x01 \x01(\x0c\x12\x12\n\npolicy_uri\x18\x07 \x01(\t\x12\x14\n\x0cpersonal_key\x18\x08 \x01(\x0c\x12\x11\n\ttimestamp\x18\n \x01(\t\x12\x14\n\x0csession_data\x18\x0b \x01(\t\x12\x12\n\nerror_code\x18\x0c \x01(\t\x12\x30\n\x06issuer\x18\r \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\x0e \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12\x1c\n\x14\x66\x61ilure_reasons_json\x18\x0f \x01(\x0c\"i\n\x0e\x46\x61ilureReasons\x12W\n\x1crequirements_not_met_details\x18\x01 \x03(\x0b\x32\x31.yoti.core.compubapi_v1.RequirementsNotMetDetailsBh\n\x17\x63om.yoti.sharepubapi_v1B\x0cReceiptProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ReceiptPush_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\014ReceiptProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _SUCCESSRECEIPT._serialized_start=135
  _SUCCESSRECEIPT._serialized_end=550
  _FAILURERECEIPT._serialized_start=553
  _FAILURERECEIPT._serialized_end=828
  _FAILUREREASONS._serialized_start=830
  _FAILUREREASONS._serialized_end=935
# @@protoc_insertion_point(module_scope)
