# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/Refresh.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from devicepubapi_v1 import StaticCredentialAuth_pb2 as devicepubapi__v1_dot_StaticCredentialAuth__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ttrpubapi_v1/Refresh.proto\x12\x17yoti.core.attrpubapi_v1\x1a*devicepubapi_v1/StaticCredentialAuth.proto\x1a\x1b\x63ompubapi_v1/Metadata.proto\"\xa7\x02\n\x0eRefreshRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\x0c\x12\x16\n\x0e\x61uth_data_list\x18\x03 \x01(\x0c\x12\x15\n\rattribute_ids\x18\x04 \x03(\x0c\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x16\n\rfeature_flags\x18\xc1\x0c \x01(\x06\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\t\x12P\n\x16static_credential_auth\x18\xb8\x17 \x01(\x0b\x32/.yoti.core.devicepubapi_v1.StaticCredentialAuth\"\xa3\x01\n\x0fRefreshResponse\x12\x41\n\x08statuses\x18\x01 \x03(\x0e\x32/.yoti.core.attrpubapi_v1.RefreshResponse.Status\"M\n\x06Status\x12\r\n\tNO_CHANGE\x10\x00\x12\x0b\n\x07REVOKED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\r\n\tNOT_FOUND\x10\x03\x12\x0b\n\x07\x45XPIRED\x10\x04\x42o\n\x16\x63om.yoti.attrpubapi_v1B\x16RefreshAttributesProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Refresh_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\026RefreshAttributesProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _REFRESHREQUEST._serialized_start=130
  _REFRESHREQUEST._serialized_end=425
  _REFRESHRESPONSE._serialized_start=428
  _REFRESHRESPONSE._serialized_end=591
  _REFRESHRESPONSE_STATUS._serialized_start=514
  _REFRESHRESPONSE_STATUS._serialized_end=591
# @@protoc_insertion_point(module_scope)
