# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/IdentityProfile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Address_pb2 as compubapi__v1_dot_Address__pb2
from . import DocumentTypes_pb2 as compubapi__v1_dot_DocumentTypes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"compubapi_v1/IdentityProfile.proto\x12\x16yoti.core.compubapi_v1\x1a\x1a\x63ompubapi_v1/Address.proto\x1a compubapi_v1/DocumentTypes.proto\"\x88\x02\n\x06Scheme\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.yoti.core.compubapi_v1.Scheme.Type\x12\x11\n\tobjective\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x34\n\x06\x63onfig\x18\x04 \x01(\x0b\x32$.yoti.core.compubapi_v1.SchemeConfig\"s\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03\x44\x42S\x10\x01\x12\x07\n\x03RTW\x10\x02\x12\x07\n\x03RTR\x10\x03\x12\x0b\n\x07\x44\x42S_RTW\x10\x04\x12\x0c\n\x08IDENTITY\x10\x05\x12\x19\n\x15IDENTITY_PLUS_ADDRESS\x10\x06\x12\x0b\n\x07\x43\x41N_CRC\x10\x07\"[\n\x0cSchemeConfig\x12K\n\x0f\x64ocument_filter\x18\x01 \x01(\x0b\x32\x32.yoti.core.compubapi_v1.DocumentRestrictionsFilter\"\x8e\x01\n\x1bIdentityProfileRequirements\x12?\n\x0ftrust_framework\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12.\n\x06scheme\x18\x02 \x01(\x0b\x32\x1e.yoti.core.compubapi_v1.Scheme\"`\n#AdvancedIdentityProfileRequirements\x12\x39\n\x08profiles\x18\x01 \x03(\x0b\x32\'.yoti.core.compubapi_v1.AdvancedProfile\"\x83\x01\n\x0f\x41\x64vancedProfile\x12?\n\x0ftrust_framework\x18\x01 \x01(\x0e\x32&.yoti.core.compubapi_v1.TrustFramework\x12/\n\x07schemes\x18\x02 \x03(\x0b\x32\x1e.yoti.core.compubapi_v1.Scheme\"\x1d\n\x07Subject\x12\x12\n\nsubject_id\x18\x01 \x01(\t\"\xc8\x01\n\x0fIdentityDetails\x12\x13\n\x0bgiven_names\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x13\n\x0bmiddle_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x11\n\tfull_name\x18\x05 \x01(\t\x12\x15\n\rdate_of_birth\x18\x06 \x01(\t\x12\x38\n\x0f\x63urrent_address\x18\x07 \x01(\x0b\x32\x1f.yoti.core.compubapi_v1.Address\"u\n\x1eVerificationReportRequirements\x12S\n\x1dgeneral_evidence_requirements\x18\x01 \x01(\x0e\x32,.yoti.core.compubapi_v1.EvidenceRequirements*A\n\x0eTrustFramework\x12\x10\n\x0cUNDEFINED_TF\x10\x00\x12\x0c\n\x08UK_TFIDA\x10\x01\x12\x0f\n\x0bYOTI_GLOBAL\x10\x02*z\n\x14\x45videnceRequirements\x12\x10\n\x0cUNDEFINED_ER\x10\x00\x12\x11\n\rOMIT_EVIDENCE\x10\x01\x12\x18\n\x14METADATA_AND_DETAILS\x10\x02\x12#\n\x1fMETADATA_AND_DETAILS_AND_IMAGES\x10\x03\x42j\n\x15\x63om.yoti.compubapi_v1B\x14IdentityProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfile_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\024IdentityProfileProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _TRUSTFRAMEWORK._serialized_start=1214
  _TRUSTFRAMEWORK._serialized_end=1279
  _EVIDENCEREQUIREMENTS._serialized_start=1281
  _EVIDENCEREQUIREMENTS._serialized_end=1403
  _SCHEME._serialized_start=125
  _SCHEME._serialized_end=389
  _SCHEME_TYPE._serialized_start=274
  _SCHEME_TYPE._serialized_end=389
  _SCHEMECONFIG._serialized_start=391
  _SCHEMECONFIG._serialized_end=482
  _IDENTITYPROFILEREQUIREMENTS._serialized_start=485
  _IDENTITYPROFILEREQUIREMENTS._serialized_end=627
  _ADVANCEDIDENTITYPROFILEREQUIREMENTS._serialized_start=629
  _ADVANCEDIDENTITYPROFILEREQUIREMENTS._serialized_end=725
  _ADVANCEDPROFILE._serialized_start=728
  _ADVANCEDPROFILE._serialized_end=859
  _SUBJECT._serialized_start=861
  _SUBJECT._serialized_end=890
  _IDENTITYDETAILS._serialized_start=893
  _IDENTITYDETAILS._serialized_end=1093
  _VERIFICATIONREPORTREQUIREMENTS._serialized_start=1095
  _VERIFICATIONREPORTREQUIREMENTS._serialized_end=1212
# @@protoc_insertion_point(module_scope)
