# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/Address.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ompubapi_v1/Address.proto\x12\x16yoti.core.compubapi_v1\"\xf4\x03\n\x07\x41\x64\x64ress\x12\x16\n\x0e\x61\x64\x64ress_format\x18\x01 \x01(\r\x12\x0f\n\x07\x63\x61re_of\x18\x02 \x01(\t\x12\x14\n\x0csub_building\x18\x03 \x01(\t\x12\x17\n\x0f\x62uilding_number\x18\x04 \x01(\t\x12\x10\n\x08\x62uilding\x18\x05 \x01(\t\x12\x0e\n\x06street\x18\x06 \x01(\t\x12\x10\n\x08landmark\x18\x07 \x01(\t\x12\x15\n\raddress_line1\x18\x08 \x01(\t\x12\x15\n\raddress_line2\x18\t \x01(\t\x12\x15\n\raddress_line3\x18\n \x01(\t\x12\x15\n\raddress_line4\x18\x0b \x01(\t\x12\x15\n\raddress_line5\x18\x0c \x01(\t\x12\x15\n\raddress_line6\x18\r \x01(\t\x12\x10\n\x08locality\x18\x0e \x01(\t\x12\x11\n\ttown_city\x18\x0f \x01(\t\x12\x13\n\x0bsubdistrict\x18\x10 \x01(\t\x12\x10\n\x08\x64istrict\x18\x11 \x01(\t\x12\r\n\x05state\x18\x12 \x01(\t\x12\x13\n\x0bpostal_code\x18\x13 \x01(\t\x12\x13\n\x0bpost_office\x18\x14 \x01(\t\x12\x13\n\x0b\x63ountry_iso\x18\x15 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x16 \x01(\t\x12\x19\n\x11\x66ormatted_address\x18\x17 \x01(\t\x12\r\n\x05udprn\x18\x18 \x01(\tBb\n\x15\x63om.yoti.compubapi_v1B\x0c\x41\x64\x64ressProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Address_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\014AddressProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _ADDRESS._serialized_start=55
  _ADDRESS._serialized_end=555
# @@protoc_insertion_point(module_scope)
