# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/DeleteSuperseded.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$attrpubapi_v1/DeleteSuperseded.proto\x12\x17yoti.core.attrpubapi_v1\x1a\x1b\x63ompubapi_v1/Metadata.proto\"\x9d\x02\n\x17\x44\x65leteSupersededRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\x0c\x12\x16\n\x0e\x61uth_data_list\x18\x03 \x01(\x0c\x12\x15\n\rattribute_ids\x18\x04 \x03(\x0c\x12\x1c\n\x14\x61ttributes_backup_id\x18\x05 \x01(\x0c\x12\x1f\n\x17\x65ncrypted_attribute_ids\x18\x06 \x03(\x0c\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x16\n\rfeature_flags\x18\xc1\x0c \x01(\x06\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\tBn\n\x16\x63om.yoti.attrpubapi_v1B\x15\x44\x65leteSupersededProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DeleteSuperseded_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\025DeleteSupersededProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _DELETESUPERSEDEDREQUEST._serialized_start=95
  _DELETESUPERSEDEDREQUEST._serialized_end=380
# @@protoc_insertion_point(module_scope)
