# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/AttributeDisplayResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,attrpubapi_v1/AttributeDisplayResponse.proto\x12\x17yoti.core.attrpubapi_v1\"(\n\x18\x41ttributeDisplayResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42v\n\x16\x63om.yoti.attrpubapi_v1B\x1d\x41ttributeDisplayResponseProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AttributeDisplayResponse_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\035AttributeDisplayResponseProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _ATTRIBUTEDISPLAYRESPONSE._serialized_start=73
  _ATTRIBUTEDISPLAYRESPONSE._serialized_end=113
# @@protoc_insertion_point(module_scope)
