# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/DataPrivacy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ompubapi_v1/DataPrivacy.proto\x12\x16yoti.core.compubapi_v1*q\n\x0b\x44\x61taPrivacy\x12\x1a\n\x16\x44\x41TA_PRIVACY_UNDEFINED\x10\x00\x12$\n DATA_PRIVACY_CONTROLLERS_ALLOWED\x10\x01\x12 \n\x1c\x44\x41TA_PRIVACY_PROCESSORS_ONLY\x10\x02\x42\x66\n\x15\x63om.yoti.compubapi_v1B\x10\x44\x61taPrivacyProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DataPrivacy_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\020DataPrivacyProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _DATAPRIVACY._serialized_start=58
  _DATAPRIVACY._serialized_end=171
# @@protoc_insertion_point(module_scope)
