# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/DocumentTypes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n compubapi_v1/DocumentTypes.proto\x12\x16yoti.core.compubapi_v1\"\xcc\x03\n\nIdDocument\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yoti.core.compubapi_v1.IdDocument.Type\x12\x18\n\x10\x63ountry_iso_code\x18\x02 \x01(\t\"\xec\x02\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x0c\n\x08PASSPORT\x10\x01\x12\x13\n\x0f\x44RIVING_LICENCE\x10\x02\x12\x0f\n\x0bNATIONAL_ID\x10\x03\x12\x0c\n\x08STATE_ID\x10\x04\x12\t\n\x05MYKAD\x10\x05\x12\x0b\n\x07\x41\x41\x44HAAR\x10\x06\x12\x07\n\x03PAN\x10\x07\x12\x0f\n\x0bSSS_ID_CARD\x10\x08\x12\r\n\tPOSTAL_ID\x10\t\x12\x14\n\x10RESIDENCE_PERMIT\x10\n\x12\x0c\n\x08VOTER_ID\x10\x0b\x12\x13\n\x0fPROFESSIONAL_ID\x10\x0c\x12\x0e\n\nNEXUS_CARD\x10\r\x12\x0f\n\x0bHEALTH_CARD\x10\x0e\x12\x0e\n\nPOSTOFFICE\x10\x0f\x12\x0e\n\nPHILSYS_ID\x10\x10\x12\x08\n\x04UMID\x10\x11\x12\x0f\n\x0b\x43ITIZENCARD\x10\x12\x12\r\n\tYOUNGSCOT\x10\x13\x12\x08\n\x04SCIS\x10\x14\x12\x13\n\x0fTRAVEL_DOCUMENT\x10\x15\x12\x0f\n\x0bWORK_PERMIT\x10\x16\"\x98\x05\n\x15SupplementaryDocument\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x32.yoti.core.compubapi_v1.SupplementaryDocument.Type\x12\x18\n\x10\x63ountry_iso_code\x18\x02 \x01(\t\"\xa2\x04\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\x10\n\x0cUTILITY_BILL\x10\x01\x12\x14\n\x10\x43OUNCIL_TAX_BILL\x10\x02\x12\x0e\n\nPHONE_BILL\x10\x03\x12\x12\n\x0e\x42\x41NK_STATEMENT\x10\x04\x12\x14\n\x10\x46IREARMS_LICENCE\x10\x05\x12\x11\n\rMILITARY_CARD\x10\x06\x12\x36\n2BIRTH_CERTIFICATE_ISSUED_WITHIN_12_MONTHS_OF_BIRTH\x10\x07\x12\x15\n\x11\x42IRTH_CERTIFICATE\x10\x08\x12\x18\n\x14\x41\x44OPTION_CERTIFICATE\x10\t\x12\x19\n\x15PAPER_DRIVING_LICENCE\x10\n\x12\x18\n\x14MARRIAGE_CERTIFICATE\x10\x0b\x12\x1a\n\x16\x41\x43\x43OUNT_OPENING_LETTER\x10\x0c\x12\x15\n\x11\x42\x45NEFIT_STATEMENT\x10\r\x12\x16\n\x12MORTGAGE_STATEMENT\x10\x0e\x12\x17\n\x13\x46INANCIAL_STATEMENT\x10\x0f\x12\x15\n\x11\x45MPLOYEE_TAX_FORM\x10\x10\x12!\n\x1d\x45MPLOYMENT_SPONSORSHIP_LETTER\x10\x11\x12\x18\n\x14IMMIGRATION_DOCUMENT\x10\x12\x12\x14\n\x10\x45\x44UCATION_LETTER\x10\x13\x12\r\n\tDVLA_FORM\x10\x14\x12\x1b\n\x17SUPPLEMENTARY_PASS_CARD\x10\x15\"l\n\x12IdDocumentSelector\x12\x15\n\rcountry_codes\x18\x01 \x03(\t\x12?\n\x0e\x64ocument_types\x18\x02 \x03(\x0e\x32\'.yoti.core.compubapi_v1.IdDocument.Type\"n\n\x1a\x44ocumentRestrictionsFilter\x12\x11\n\tallowlist\x18\x01 \x01(\x08\x12=\n\tdocuments\x18\x02 \x03(\x0b\x32*.yoti.core.compubapi_v1.IdDocumentSelectorBh\n\x15\x63om.yoti.compubapi_v1B\x12\x44ocumentTypesProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DocumentTypes_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\022DocumentTypesProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _IDDOCUMENT._serialized_start=61
  _IDDOCUMENT._serialized_end=521
  _IDDOCUMENT_TYPE._serialized_start=157
  _IDDOCUMENT_TYPE._serialized_end=521
  _SUPPLEMENTARYDOCUMENT._serialized_start=524
  _SUPPLEMENTARYDOCUMENT._serialized_end=1188
  _SUPPLEMENTARYDOCUMENT_TYPE._serialized_start=642
  _SUPPLEMENTARYDOCUMENT_TYPE._serialized_end=1188
  _IDDOCUMENTSELECTOR._serialized_start=1190
  _IDDOCUMENTSELECTOR._serialized_end=1298
  _DOCUMENTRESTRICTIONSFILTER._serialized_start=1300
  _DOCUMENTRESTRICTIONSFILTER._serialized_end=1410
# @@protoc_insertion_point(module_scope)
