# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sharepubapi_v1/IdentityProfileShare.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Policy_pb2 as sharepubapi__v1_dot_Policy__pb2
from . import Sharing_pb2 as sharepubapi__v1_dot_Sharing__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import Metadata_pb2 as compubapi__v1_dot_Metadata__pb2
from yoti_python_sdk.protobuf.compubapi_v1 import DocumentTypes_pb2 as compubapi__v1_dot_DocumentTypes__pb2
from devicepubapi_v1 import StaticCredentialAuth_pb2 as devicepubapi__v1_dot_StaticCredentialAuth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)sharepubapi_v1/IdentityProfileShare.proto\x12\x18yoti.core.sharepubapi_v1\x1a\x1bsharepubapi_v1/Policy.proto\x1a\x1csharepubapi_v1/Sharing.proto\x1a\x1b\x63ompubapi_v1/Metadata.proto\x1a compubapi_v1/DocumentTypes.proto\x1a*devicepubapi_v1/StaticCredentialAuth.proto\"\xf9\x04\n\x0fNextStepRequest\x12\x12\n\ncredential\x18\x01 \x01(\x0c\x12\x13\n\x0bwrapped_key\x18\x02 \x01(\x0c\x12\x16\n\x0e\x61uth_data_list\x18\x03 \x01(\x0c\x12\x30\n\x06policy\x18\x04 \x01(\x0b\x32 .yoti.core.sharepubapi_v1.Policy\x12\x15\n\rsharing_token\x18\x05 \x01(\x0c\x12\x14\n\x0csession_data\x18\x06 \x01(\t\x12\x30\n\x06issuer\x18\x07 \x01(\x0e\x32 .yoti.core.sharepubapi_v1.Issuer\x12\x36\n\ttransport\x18\x08 \x01(\x0e\x32#.yoti.core.sharepubapi_v1.Transport\x12!\n\x19user_profile_attribute_id\x18\t \x01(\x0c\x12M\n\x11unable_to_provide\x18\n \x01(\x0b\x32\x32.yoti.core.compubapi_v1.DocumentRestrictionsFilter\x12\x15\n\rattribute_ids\x18\x0b \x03(\x0c\x12\x14\n\x0creference_id\x18\x0c \x01(\t\x12:\n\x0f\x64\x65vice_metadata\x18\xc0\x0c \x01(\x0b\x32 .yoti.core.compubapi_v1.Metadata\x12\x16\n\rfeature_flags\x18\xc1\x0c \x01(\x06\x12\x17\n\x0e\x63orrelation_id\x18\xc2\x0c \x01(\t\x12P\n\x16static_credential_auth\x18\xb8\x17 \x01(\x0b\x32/.yoti.core.devicepubapi_v1.StaticCredentialAuth\"\xfc\x04\n\x10NextStepResponse\x12?\n\x05state\x18\x01 \x01(\x0e\x32\x30.yoti.core.sharepubapi_v1.NextStepResponse.State\x12?\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\x0b\x32\'.yoti.core.sharepubapi_v1.FailureReason\x12:\n\x0brequirement\x18\x03 \x01(\x0b\x32%.yoti.core.sharepubapi_v1.Requirement\x12\x43\n\x10progress_summary\x18\x04 \x01(\x0b\x32).yoti.core.sharepubapi_v1.ProgressSummary\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12\x46\n\x12unusable_documents\x18\x06 \x03(\x0b\x32*.yoti.core.sharepubapi_v1.UnusableDocument\x12m\n\x1esubsequent_next_step_may_abort\x18\x07 \x01(\x0e\x32\x45.yoti.core.sharepubapi_v1.NextStepResponse.SubsequentNextStepMayAbort\"V\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x12\x16\n\x12NEXT_STEP_REQUIRED\x10\x02\x12\x0c\n\x08\x44\x45\x41\x44_END\x10\x03\x12\x0e\n\nCALL_AGAIN\x10\x04\"E\n\x1aSubsequentNextStepMayAbort\x12\x12\n\x0eNOT_APPLICABLE\x10\x00\x12\t\n\x05\x46\x41LSE\x10\x01\x12\x08\n\x04TRUE\x10\x02\"\xc8\x01\n\x10UnusableDocument\x12\x34\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\".yoti.core.compubapi_v1.IdDocument\x12\x41\n\x06reason\x18\x02 \x01(\x0e\x32\x31.yoti.core.sharepubapi_v1.UnusableDocument.Reason\";\n\x06Reason\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07\x45XPIRED\x10\x01\x12\x15\n\x11OVERSEAS_PASSPORT\x10\x02\"\xde\x01\n\x0fProgressSummary\x12=\n\x0bproof_of_id\x18\x01 \x01(\x0b\x32(.yoti.core.sharepubapi_v1.CategoryStatus\x12\x42\n\x10proof_of_address\x18\x02 \x01(\x0b\x32(.yoti.core.sharepubapi_v1.CategoryStatus\x12H\n\x16\x62iometric_verification\x18\x03 \x01(\x0b\x32(.yoti.core.sharepubapi_v1.CategoryStatus\"$\n\rFailureReason\x12\x13\n\x0breason_code\x18\x01 \x01(\t\"\xf7\x01\n\x0e\x43\x61tegoryStatus\x12=\n\x05state\x18\x01 \x01(\x0e\x32..yoti.core.sharepubapi_v1.CategoryStatus.State\x12N\n\x16\x66ulfilled_requirements\x18\x02 \x03(\x0b\x32..yoti.core.sharepubapi_v1.FulfilledRequirement\"V\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x12\x0e\n\nTO_BE_DONE\x10\x02\x12\x0e\n\nNOT_NEEDED\x10\x03\x12\x14\n\x10NO_LONGER_NEEDED\x10\x04\"\x99\x01\n\x14\x46ulfilledRequirement\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.yoti.core.sharepubapi_v1.Requirement.Type\x12\x34\n\x08\x64ocument\x18\x02 \x01(\x0b\x32\".yoti.core.compubapi_v1.IdDocument\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"\xaf\x03\n\x0bRequirement\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.yoti.core.sharepubapi_v1.Requirement.Type\x12W\n\x14requirement_category\x18\x02 \x01(\x0e\x32\x39.yoti.core.sharepubapi_v1.Requirement.RequirementCategory\x12M\n\x15\x64ocument_restrictions\x18\x03 \x01(\x0b\x32..yoti.core.sharepubapi_v1.DocumentRestrictions\"R\n\x04Type\x12\x10\n\x0cUNDEFINED_RT\x10\x00\x12\x0f\n\x0bID_DOCUMENT\x10\x01\x12\x12\n\x0eMANUAL_ADDRESS\x10\x02\x12\x13\n\x0f\x43ONFIRM_ADDRESS\x10\x03\"j\n\x13RequirementCategory\x12\x10\n\x0cUNDEFINED_RC\x10\x00\x12\x0f\n\x0bPROOF_OF_ID\x10\x01\x12\x14\n\x10PROOF_OF_ADDRESS\x10\x02\x12\x1a\n\x16\x42IOMETRIC_VERIFICATION\x10\x03\"\x81\x01\n\x14\x44ocumentRestrictions\x12%\n\x1d\x63hip_verification_recommended\x18\x01 \x01(\x08\x12\x42\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x32.yoti.core.compubapi_v1.DocumentRestrictionsFilterBu\n\x17\x63om.yoti.sharepubapi_v1B\x19IdentityProfileShareProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\xba\x02\x0eSharepubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IdentityProfileShare_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yoti.sharepubapi_v1B\031IdentityProfileShareProtoZ.go.internal.yoti.com/proto/core/sharepubapi_v1\272\002\016SharepubapiV1_'
  _NEXTSTEPREQUEST._serialized_start=238
  _NEXTSTEPREQUEST._serialized_end=871
  _NEXTSTEPRESPONSE._serialized_start=874
  _NEXTSTEPRESPONSE._serialized_end=1510
  _NEXTSTEPRESPONSE_STATE._serialized_start=1353
  _NEXTSTEPRESPONSE_STATE._serialized_end=1439
  _NEXTSTEPRESPONSE_SUBSEQUENTNEXTSTEPMAYABORT._serialized_start=1441
  _NEXTSTEPRESPONSE_SUBSEQUENTNEXTSTEPMAYABORT._serialized_end=1510
  _UNUSABLEDOCUMENT._serialized_start=1513
  _UNUSABLEDOCUMENT._serialized_end=1713
  _UNUSABLEDOCUMENT_REASON._serialized_start=1654
  _UNUSABLEDOCUMENT_REASON._serialized_end=1713
  _PROGRESSSUMMARY._serialized_start=1716
  _PROGRESSSUMMARY._serialized_end=1938
  _FAILUREREASON._serialized_start=1940
  _FAILUREREASON._serialized_end=1976
  _CATEGORYSTATUS._serialized_start=1979
  _CATEGORYSTATUS._serialized_end=2226
  _CATEGORYSTATUS_STATE._serialized_start=2140
  _CATEGORYSTATUS_STATE._serialized_end=2226
  _FULFILLEDREQUIREMENT._serialized_start=2229
  _FULFILLEDREQUIREMENT._serialized_end=2382
  _REQUIREMENT._serialized_start=2385
  _REQUIREMENT._serialized_end=2816
  _REQUIREMENT_TYPE._serialized_start=2626
  _REQUIREMENT_TYPE._serialized_end=2708
  _REQUIREMENT_REQUIREMENTCATEGORY._serialized_start=2710
  _REQUIREMENT_REQUIREMENTCATEGORY._serialized_end=2816
  _DOCUMENTRESTRICTIONS._serialized_start=2819
  _DOCUMENTRESTRICTIONS._serialized_end=2948
# @@protoc_insertion_point(module_scope)
