# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: attrpubapi_v1/Attribute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ttrpubapi_v1/Attribute.proto\x12\x17yoti.core.attrpubapi_v1\"\x9a\x01\n\nMultiValue\x12\x39\n\x06values\x18\x01 \x03(\x0b\x32).yoti.core.attrpubapi_v1.MultiValue.Value\x1aQ\n\x05Value\x12:\n\x0c\x63ontent_type\x18\x01 \x01(\x0e\x32$.yoti.core.attrpubapi_v1.ContentType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x9f\x02\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12:\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32$.yoti.core.attrpubapi_v1.ContentType\x12\x30\n\x07\x61nchors\x18\x04 \x03(\x0b\x32\x1f.yoti.core.attrpubapi_v1.Anchor\x12<\n\ruser_metadata\x18\x05 \x03(\x0b\x32%.yoti.core.attrpubapi_v1.UserMetadata\x12\x33\n\x08metadata\x18\x06 \x01(\x0b\x32!.yoti.core.attrpubapi_v1.Metadata\x12\x14\n\x0c\x65phemeral_id\x18\x07 \x01(\t\"\xa0\x01\n\x08Metadata\x12\x1d\n\x15superseded_time_stamp\x18\x01 \x01(\t\x12\x11\n\tdeletable\x18\x02 \x01(\x08\x12\x12\n\nreceipt_id\x18\x03 \x01(\x0c\x12\x0f\n\x07revoked\x18\x04 \x01(\x08\x12\x0e\n\x06locked\x18\x05 \x01(\x08\x12\x1c\n\x14\x65xtended_expiry_date\x18\x06 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x07 \x01(\x08\"\xb3\x01\n\x06\x41nchor\x12\x15\n\rartifact_link\x18\x01 \x01(\x0c\x12\x1b\n\x13origin_server_certs\x18\x02 \x03(\x0c\x12\x1a\n\x12\x61rtifact_signature\x18\x03 \x01(\x0c\x12\x10\n\x08sub_type\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x05 \x01(\x0c\x12\x19\n\x11signed_time_stamp\x18\x06 \x01(\x0c\x12\x19\n\x11\x61ssociated_source\x18\x07 \x01(\t\"*\n\x0cUserMetadata\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*u\n\x0b\x43ontentType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x08\n\x04JPEG\x10\x02\x12\x08\n\x04\x44\x41TE\x10\x03\x12\x07\n\x03PNG\x10\x04\x12\x08\n\x04JSON\x10\x05\x12\x0f\n\x0bMULTI_VALUE\x10\x06\x12\x07\n\x03INT\x10\x07\x12\n\n\x06JWT_VC\x10\x08\x42g\n\x16\x63om.yoti.attrpubapi_v1B\x0e\x41ttributeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\xba\x02\rAttrpubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Attribute_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yoti.attrpubapi_v1B\016AttributeProtoZ-go.internal.yoti.com/proto/core/attrpubapi_v1\272\002\rAttrpubapiV1_'
  _CONTENTTYPE._serialized_start=894
  _CONTENTTYPE._serialized_end=1011
  _MULTIVALUE._serialized_start=59
  _MULTIVALUE._serialized_end=213
  _MULTIVALUE_VALUE._serialized_start=132
  _MULTIVALUE_VALUE._serialized_end=213
  _ATTRIBUTE._serialized_start=216
  _ATTRIBUTE._serialized_end=503
  _METADATA._serialized_start=506
  _METADATA._serialized_end=666
  _ANCHOR._serialized_start=669
  _ANCHOR._serialized_end=848
  _USERMETADATA._serialized_start=850
  _USERMETADATA._serialized_end=892
# @@protoc_insertion_point(module_scope)
