# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compubapi_v1/Signature.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63ompubapi_v1/Signature.proto\x12\x16yoti.core.compubapi_v1\"\xb0\x01\n\tSignature\x12\x39\n\x04\x61lgo\x18\x01 \x01(\x0e\x32+.yoti.core.compubapi_v1.Signature.Algorithm\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\"[\n\tAlgorithm\x12\r\n\tUNDEFINED\x10\x00\x12\x12\n\x0eRSA_PSS_SHA512\x10\x01\x12\x12\n\x0eRSA_PSS_SHA256\x10\x02\x12\x17\n\x13RSA_PKCS1V15_SHA256\x10\x03\x42\x64\n\x15\x63om.yoti.compubapi_v1B\x0eSignatureProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\xba\x02\x0c\x43ompubapiV1_b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Signature_pb2.py', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.yoti.compubapi_v1B\016SignatureProtoZ,go.internal.yoti.com/proto/core/compubapi_v1\272\002\014CompubapiV1_'
  _SIGNATURE._serialized_start=57
  _SIGNATURE._serialized_end=233
  _SIGNATURE_ALGORITHM._serialized_start=142
  _SIGNATURE_ALGORITHM._serialized_end=233
# @@protoc_insertion_point(module_scope)
